@@ -80,6 +80,11 @@ def hello_world(args: 'Namespace'):
     hello_world(args)
 
 
+def hello_world_chatbot(args: 'Namespace'):
+    from jina.helloworld.chatbot import hello_world
+    hello_world(args)
+
+
 def flow(args: 'Namespace'):
     """Start a Flow from a YAML file or a docker image"""
     from jina.flow import Flow
@@ -91,6 +96,7 @@ def flow(args: 'Namespace'):
         from jina.logging import default_logger
         default_logger.critical('start a flow from CLI requires a valid "--uses"')
 
+
 def optimizer(args: 'Namespace'):
     """Start an optimization from a YAML file"""
     from jina.optimizers import run_optimizer_cli
