@@ -16,8 +16,7 @@ Welcome to Jina daemon - the manager of distributed Jina
 💬 Swagger UI     :\thttp://localhost:{jinad_args.port_expose}/docs
 📚 Redoc          :\thttp://localhost:{jinad_args.port_expose}/redoc
 🔒 Private address:\thttp://{get_internal_ip()}:{jinad_args.port_expose}
-🌐 Public address :\thttp://{get_public_ip()}:{jinad_args.port_expose}
-    ''')
+🌐 Public address :\thttp://{get_public_ip()}:{jinad_args.port_expose}''')
     from jina import __ready_msg__
     daemon_logger.success(__ready_msg__)
 
