@@ -22,6 +22,7 @@ from ..helper import convert_tuple_to_list
 from ..jaml import JAMLCompatible
 from ..types.querylang import QueryLang
 
+# noinspection PyUnreachableCode
 if False:
     # fix type-hint complain for sphinx and flake
     from ..peapods.runtimes.zmq.zed import ZEDRuntime
@@ -34,10 +35,14 @@ if False:
 
 
 def store_init_kwargs(func: Callable) -> Callable:
-    """Mark the args and kwargs of :func:`__init__` later to be stored via :func:`save_config` in YAML """
+    """Mark the args and kwargs of :func:`__init__` later to be stored via :func:`save_config` in YAML
+
+    :param func: the Callable to wrap
+    :return: the wrapped Callable
+    """
 
     @wraps(func)
-    def arg_wrapper(self, *args, **kwargs):
+    def _arg_wrapper(self, *args, **kwargs):
         if func.__name__ != '__init__':
             raise TypeError(
                 'this decorator should only be used on __init__ method of a driver'
@@ -68,11 +73,12 @@ def store_init_kwargs(func: Callable) -> Callable:
         f = func(self, *args, **kwargs)
         return f
 
-    return arg_wrapper
+    return _arg_wrapper
 
 
 class QuerySetReader:
-    """:class:`QuerySetReader` allows a driver to read arguments from the protobuf message. This allows a
+    """
+    :class:`QuerySetReader` allows a driver to read arguments from the protobuf message. This allows a
     driver to override its behavior based on the message it receives. Extremely useful in production, for example,
     get ``top_k`` results, doing pagination, filtering.
 
@@ -94,7 +100,6 @@ class QuerySetReader:
 
     .. warning::
         For the sake of cooperative multiple inheritance, do NOT implement :meth:`__init__` for this class
-
     """
 
     @property
@@ -158,16 +163,15 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
     A :class:`BaseDriver` needs to be :attr:`attached` to a :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` before
     using. This is done by :func:`attach`. Note that a deserialized :class:`BaseDriver` from file is always unattached.
 
+    :param priority: the priority of its default arg values (hardcoded in Python). If the
+         received ``QueryLang`` has a higher priority, it will override the hardcoded value
+    :param *args: not used (kept to maintain interface)
+    :param **kwargs: not used (kept to maintain interface)
     """
 
     store_args_kwargs = False  #: set this to ``True`` to save ``args`` (in a list) and ``kwargs`` (in a map) in YAML config
 
     def __init__(self, priority: int = 0, *args, **kwargs):
-        """
-
-        :param priority: the priority of its default arg values (hardcoded in Python). If the
-             received ``QueryLang`` has a higher priority, it will override the hardcoded value
-        """
         self.attached = False  # : represent if this driver is attached to a
         # :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` (& :class:`jina.executors.BaseExecutor`)
         self.runtime = None  # type: Optional['ZEDRuntime']
@@ -176,7 +180,9 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
     def attach(self, runtime: 'ZEDRuntime', *args, **kwargs) -> None:
         """Attach this driver to a :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime`
 
-        :param runtime: the pea to be attached.
+        :param runtime: the pea to be attached
+        :param *args: not used (kept to maintain interface)
+        :param **kwargs: not used (kept to maintain interface)
         """
         self.runtime = runtime
         self.attached = True
@@ -246,6 +252,7 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
         Unlike `Executor`, driver is stateless.
 
         Therefore, on every save, it creates a new & empty driver object and save it.
+        :return: the state in dict form
         """
 
         d = dict(self.__class__(**self._init_kwargs_dict).__dict__)
@@ -253,10 +260,12 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
 
 
 class BaseRecursiveDriver(BaseDriver):
+    """A Driver to traverse a set of Documents with a specific path.
+
+    :param traversal_paths: The describes the leaves of the document tree on which _apply_all are called
+    """
+
     def __init__(self, traversal_paths: Tuple[str] = ('c', 'r'), *args, **kwargs):
-        """
-        :param traversal_paths: The describes the leaves of the document tree on which _apply_all are called
-        """
         super().__init__(*args, **kwargs)
         self._traversal_paths = [path.lower() for path in traversal_paths]
 
@@ -284,6 +293,8 @@ class BaseRecursiveDriver(BaseDriver):
         :param docs: a list of :class:`jina.Document` objects to work on; they could come from ``matches``/``chunks``.
         :param context_doc: the owner of ``docs``
         :param field: where ``docs`` comes from, either ``matches`` or ``chunks``
+        :param *args: *args
+        :param **kwargs: **kwargs
         """
 
     def __call__(self, *args, **kwargs):
@@ -333,6 +344,8 @@ class BaseExecutableDriver(BaseRecursiveDriver):
 
         :param executor: the name of the sub-executor, only necessary when :class:`jina.executors.compound.CompoundExecutor` is used
         :param method: the function name of the executor that the driver feeds to
+        :param *args: *args for super
+        :param **kwargs: **kwargs for super
         """
         super().__init__(*args, **kwargs)
         self._executor_name = executor
@@ -342,12 +355,15 @@ class BaseExecutableDriver(BaseRecursiveDriver):
 
     @property
     def exec(self) -> 'AnyExecutor':
-        """the executor that attached """
+        """the executor that to which the instance is attached"""
         return self._exec
 
     @property
     def exec_fn(self) -> Callable:
-        """the function of :func:`jina.executors.BaseExecutor` to call """
+        """the function of :func:`jina.executors.BaseExecutor` to call
+
+        :return: the Callable to execute in the driver
+        """
         if (
             not self.msg.is_error
             or self.runtime.args.on_error_strategy < OnErrorStrategy.SKIP_EXECUTOR
@@ -357,7 +373,12 @@ class BaseExecutableDriver(BaseRecursiveDriver):
             return lambda *args, **kwargs: None
 
     def attach(self, executor: 'AnyExecutor', *args, **kwargs) -> None:
-        """Attach the driver to a :class:`jina.executors.BaseExecutor`"""
+        """Attach the driver to a :class:`jina.executors.BaseExecutor`
+
+        :param executor: the executor to which we attach
+        :param *args: *args for super().attach()
+        :param **kwargs: **kwargs for super().attach()
+        """
         super().attach(*args, **kwargs)
         if self._executor_name and isinstance(executor, CompoundExecutor):
             if self._executor_name in executor:
@@ -388,7 +409,10 @@ class BaseExecutableDriver(BaseRecursiveDriver):
 
     def __getstate__(self) -> Dict[str, Any]:
         """Do not save the executor and executor function, as it would be cross-referencing and unserializable.
-        In other words, a deserialized :class:`BaseExecutableDriver` from file is always unattached."""
+        In other words, a deserialized :class:`BaseExecutableDriver` from file is always unattached.
+
+        :return: dictionary of state
+        """
         d = super().__getstate__()
         if '_exec' in d:
             del d['_exec']
