@@ -5,7 +5,17 @@ if False:
 
 
 class ConvertDriver(BaseRecursiveDriver):
+    """Drivers that make sure that specific conversions are applied to the documents.
+
+    .. note::
+        The list of functions that can be applied can be found in `:class:`Document`
+     """
     def __init__(self, convert_fn: str, *args, **kwargs):
+        """
+        :param convert_fn: the method name from `:class:`Document` to be applied
+        :param *args:
+        :param **kwargs: the set of named arguments to be passed to the method with name `convert_fn`
+        """
         super().__init__(*args, **kwargs)
         self._convert_fn = convert_fn
         self._convert_fn_kwargs = kwargs
