@@ -1,15 +1,8 @@
 from functools import partial
 from typing import Callable, List, Type, Union, Iterable
 
+from ....excepts import LookupyError
 
-## Exceptions
-
-class LookupyError(Exception):
-    """Base exception class for all exceptions raised by lookupy"""
-    pass
-
-
-## utility functions
 
 def iff(precond: Callable, val: Union[int, str], f: Callable) -> bool:
     """If and only if the precond is True
@@ -18,9 +11,9 @@ def iff(precond: Callable, val: Union[int, str], f: Callable) -> bool:
     to create partial functions for commonly required preconditions
 
     :param precond : (function) represents the precondition
-    :param val     : (mixed) value to which the functions are applied
-    :param f       : (function) the actual function
-
+    :param val: (mixed) value to which the functions are applied
+    :param f: (function) the actual function
+    :return: whether or not the cond is satisfied
     """
     return False if not precond(val) else f(val)
 
