@@ -1,12 +1,12 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
-from typing import Iterable
+from typing import Tuple
 
 from .. import QuerySetReader, BaseRecursiveDriver
 
 if False:
-    from ...proto import jina_pb2
+    from ...types.sets import DocumentSet
 
 
 class ReverseQL(QuerySetReader, BaseRecursiveDriver):
@@ -20,13 +20,9 @@ class ReverseQL(QuerySetReader, BaseRecursiveDriver):
 
         will reverse the order of the documents returned by the `Chunk2DocRankerDriver` before sending them to the next `Pod`
     """
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.is_apply = False
 
-    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs) -> None:
-        prev_len = len(docs)
-        for d in reversed(docs):
-            dd = docs.add()
-            dd.CopyFrom(d)
-        del docs[:prev_len]
+    def __init__(self, traversal_paths: Tuple[str] = ('r',), *args, **kwargs):
+        super().__init__(traversal_paths=traversal_paths, *args, **kwargs)
+
+    def _apply_all(self, docs: 'DocumentSet', *args, **kwargs) -> None:
+        docs.reverse()
