@@ -32,10 +32,13 @@ class SortQL(QuerySetReader, BaseRecursiveDriver):
         `SortQL` will ensure that only the documents are sorted by the score value before slicing the first top 50 documents
     """
 
-    def __init__(self, field: str, reverse: bool = False, traversal_paths: Tuple[str] = ('c',), *args, **kwargs):
+    def __init__(self, field: str, reverse: bool = False, traversal_paths: Tuple[str] = ('r',), *args, **kwargs):
         """
         :param field: the value of the field drives the sort of the iterable docs
         :param reverse: sort the value from big to small
+        :param traversal_paths: the traversal paths
+        :param *args: *args
+        :param **kwargs: **kwargs
         """
 
         super().__init__(traversal_paths=traversal_paths, *args, **kwargs)
