@@ -40,16 +40,22 @@ class BinaryPbIndexer(BaseKVIndexer):
         def close(self):
             self._body.close()
 
-    def get_add_handler(self):
+    def get_add_handler(self) -> 'WriteHandler':
+        """Get write file handler.
+        """
         # keep _start position as in pickle serialization
         return self.WriteHandler(self.index_abspath, 'ab')
 
-    def get_create_handler(self):
+    def get_create_handler(self) -> 'WriteHandler':
+        """Get write file handler.
+        """
         self._start = 0  # override _start position
         return self.WriteHandler(self.index_abspath, 'wb')
 
-    def get_query_handler(self):
-        return self.ReadHandler(self.index_abspath, self._key_length)
+    def get_query_handler(self) -> 'ReadHandler':
+        """Get read file handler.
+        """
+        return self.ReadHandler(self.index_abspath, self.key_length)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -57,7 +63,7 @@ class BinaryPbIndexer(BaseKVIndexer):
         self._start = 0
         self._page_size = mmap.ALLOCATIONGRANULARITY
 
-    def add(self, keys: Iterable[str], values: Iterable[bytes], *args, **kwargs):
+    def add(self, keys: Iterable[str], values: Iterable[bytes], *args, **kwargs) -> None:
         """Add the serialized documents to the index via document ids.
 
         :param keys: a list of ``id``, i.e. ``doc.id`` in protobuf
@@ -65,7 +71,6 @@ class BinaryPbIndexer(BaseKVIndexer):
         """
         if not keys:
             return
-        self._assert_key_length(keys)
 
         for key, value in zip(keys, values):
             l = len(value)  #: the length
@@ -74,7 +79,7 @@ class BinaryPbIndexer(BaseKVIndexer):
             self.write_handler.header.write(
                 np.array(
                     (key, p, r, r + l),
-                    dtype=[('', (np.str_, self._key_length)), ('', np.int64), ('', np.int64), ('', np.int64)]
+                    dtype=[('', (np.str_, self.key_length)), ('', np.int64), ('', np.int64), ('', np.int64)]
                 ).tobytes()
             )
             self._start += l
@@ -94,7 +99,7 @@ class BinaryPbIndexer(BaseKVIndexer):
             with mmap.mmap(self.query_handler.body, offset=p, length=l) as m:
                 return m[r:]
 
-    def update(self, keys: Iterable[str], values: Iterable[bytes], *args, **kwargs):
+    def update(self, keys: Iterable[str], values: Iterable[bytes], *args, **kwargs) -> None:
         """Update the serialized documents on the index via document ids.
 
         :param keys: a list of ``id``, i.e. ``doc.id`` in protobuf
@@ -104,14 +109,14 @@ class BinaryPbIndexer(BaseKVIndexer):
         self._delete(keys)
         self.add(keys, values)
 
-    def _delete(self, keys: Iterable[str]):
+    def _delete(self, keys: Iterable[str]) -> None:
         self.query_handler.close()
         self.handler_mutex = False
         for key in keys:
             self.write_handler.header.write(
                 np.array(
                     tuple(np.concatenate([[key], HEADER_NONE_ENTRY])),
-                    dtype=[('', (np.str_, self._key_length)), ('', np.int64), ('', np.int64), ('', np.int64)]
+                    dtype=[('', (np.str_, self.key_length)), ('', np.int64), ('', np.int64), ('', np.int64)]
                 ).tobytes()
             )
 
@@ -119,7 +124,7 @@ class BinaryPbIndexer(BaseKVIndexer):
                 del self.query_handler.header[key]
             self._size -= 1
 
-    def delete(self, keys: Iterable[str], *args, **kwargs):
+    def delete(self, keys: Iterable[str], *args, **kwargs) -> None:
         """Delete the serialized documents from the index via document ids.
 
         :param keys: a list of ``id``, i.e. ``doc.id`` in protobuf
