@@ -11,11 +11,6 @@ from jina.executors.devices import TorchDevice
 from jina.executors.encoders import BaseEncoder
 
 
-def no_grad():
-    import torch
-    return torch.no_grad()
-
-
 class TransformerTorchEncoder(TorchDevice, BaseEncoder):
     """
     Internally, TransformerTorchEncoder wraps the pytorch version of transformers from huggingface.
@@ -29,7 +24,6 @@ class TransformerTorchEncoder(TorchDevice, BaseEncoder):
             layer_index: int = -1,
             max_length: Optional[int] = None,
             acceleration: Optional[str] = None,
-            model_save_path: Optional[str] = None,
             *args,
             **kwargs,
     ):
@@ -52,11 +46,6 @@ class TransformerTorchEncoder(TorchDevice, BaseEncoder):
             ..note::
                 While acceleration methods can significantly speed up the encoding, they result in loss of precision.
                 Make sure that the tradeoff is worthwhile for your use case.
-
-        :param model_save_path: the path of the encoder model. If a valid path is given, the encoder will be saved to the given path
-
-        ..warning::
-            `model_save_path` should be relative to executor's workspace
         """
 
         super().__init__(*args, **kwargs)
@@ -66,7 +55,6 @@ class TransformerTorchEncoder(TorchDevice, BaseEncoder):
         self.layer_index = layer_index
         self.max_length = max_length
         self.acceleration = acceleration
-        self.model_save_path = model_save_path
 
         if self.pooling_strategy == 'auto':
             self.pooling_strategy = 'cls'
@@ -89,22 +77,6 @@ class TransformerTorchEncoder(TorchDevice, BaseEncoder):
             )
             raise NotImplementedError
 
-    def __getstate__(self):
-        if self.model_save_path:
-            if not os.path.exists(self.model_abspath):
-                self.logger.info(
-                    f'create folder for saving transformer models: {self.model_abspath}'
-                )
-                os.mkdir(self.model_abspath)
-            self.model.save_pretrained(self.model_abspath)
-            self.tokenizer.save_pretrained(self.model_abspath)
-        return super().__getstate__()
-
-    @property
-    def model_abspath(self) -> str:
-        """Get the file path of the encoder model storage"""
-        return self.get_file_from_workspace(self.model_save_path)
-
     def post_init(self):
         import torch
         from transformers import AutoModel, AutoTokenizer
@@ -129,7 +101,6 @@ class TransformerTorchEncoder(TorchDevice, BaseEncoder):
         else:
             return nullcontext()
 
-    @no_grad()
     @batching
     @as_ndarray
     def encode(self, data: 'np.ndarray', *args, **kwargs) -> 'np.ndarray':
@@ -139,56 +110,58 @@ class TransformerTorchEncoder(TorchDevice, BaseEncoder):
         """
         import torch
 
-        if not self.tokenizer.pad_token:
-            self.tokenizer.add_special_tokens({'pad_token': '[PAD]'})
-            self.model.resize_token_embeddings(len(self.tokenizer.vocab))
+        with torch.no_grad():
 
-        input_tokens = self.tokenizer(
-            list(data),
-            max_length=self.max_length,
-            padding='longest',
-            truncation=True,
-            return_tensors='pt',
-        )
-        input_tokens = {k: v.to(self.device) for k, v in input_tokens.items()}
+            if not self.tokenizer.pad_token:
+                self.tokenizer.add_special_tokens({'pad_token': '[PAD]'})
+                self.model.resize_token_embeddings(len(self.tokenizer.vocab))
 
-        with self.amp_accelerate():
-            outputs = self.model(**input_tokens)
-
-        n_layers = len(outputs.hidden_states)
-        if self.layer_index not in list(range(-n_layers, n_layers)):
-            self.logger.error(
-                f'Invalid value {self.layer_index} for `layer_index`,'
-                f' for the model {self.pretrained_model_name_or_path}'
-                f' valid values are integers from {-n_layers} to {n_layers - 1}.'
+            input_tokens = self.tokenizer(
+                list(data),
+                max_length=self.max_length,
+                padding='longest',
+                truncation=True,
+                return_tensors='pt',
             )
-            raise ValueError
+            input_tokens = {k: v.to(self.device) for k, v in input_tokens.items()}
 
-        if self.pooling_strategy == 'cls' and not self.tokenizer.cls_token:
-            self.logger.error(
-                f'You have set pooling_strategy to "cls", but the tokenizer'
-                f' for the model {self.pretrained_model_name_or_path}'
-                f' does not have a cls token set.'
-            )
-            raise ValueError
+            with self.amp_accelerate():
+                outputs = self.model(**input_tokens)
 
-        fill_vals = {'cls': 0.0, 'mean': 0.0, 'max': -np.inf, 'min': np.inf}
-        fill_val = torch.tensor(fill_vals[self.pooling_strategy], device=self.device)
+            n_layers = len(outputs.hidden_states)
+            if self.layer_index not in list(range(-n_layers, n_layers)):
+                self.logger.error(
+                    f'Invalid value {self.layer_index} for `layer_index`,'
+                    f' for the model {self.pretrained_model_name_or_path}'
+                    f' valid values are integers from {-n_layers} to {n_layers - 1}.'
+                )
+                raise ValueError
 
-        layer = outputs.hidden_states[self.layer_index]
-        attn_mask = input_tokens['attention_mask'].unsqueeze(-1).expand_as(layer)
-        layer = torch.where(attn_mask.bool(), layer, fill_val)
+            if self.pooling_strategy == 'cls' and not self.tokenizer.cls_token:
+                self.logger.error(
+                    f'You have set pooling_strategy to "cls", but the tokenizer'
+                    f' for the model {self.pretrained_model_name_or_path}'
+                    f' does not have a cls token set.'
+                )
+                raise ValueError
 
-        if self.pooling_strategy == 'cls':
-            CLS = self.tokenizer.cls_token_id
-            ind = torch.nonzero(input_tokens['input_ids'] == CLS)[:, 1]
-            ind = ind.unsqueeze(-1).unsqueeze(-1).expand(-1, -1, layer.shape[2])
-            embeddings = torch.gather(layer, 1, ind).squeeze(dim=1)
-        elif self.pooling_strategy == 'mean':
-            embeddings = layer.sum(dim=1) / attn_mask.sum(dim=1)
-        elif self.pooling_strategy == 'max':
-            embeddings = layer.max(dim=1).values
-        elif self.pooling_strategy == 'min':
-            embeddings = layer.min(dim=1).values
+            fill_vals = {'cls': 0.0, 'mean': 0.0, 'max': -np.inf, 'min': np.inf}
+            fill_val = torch.tensor(fill_vals[self.pooling_strategy], device=self.device)
 
-        return embeddings.cpu().numpy()
+            layer = outputs.hidden_states[self.layer_index]
+            attn_mask = input_tokens['attention_mask'].unsqueeze(-1).expand_as(layer)
+            layer = torch.where(attn_mask.bool(), layer, fill_val)
+
+            if self.pooling_strategy == 'cls':
+                CLS = self.tokenizer.cls_token_id
+                ind = torch.nonzero(input_tokens['input_ids'] == CLS)[:, 1]
+                ind = ind.unsqueeze(-1).unsqueeze(-1).expand(-1, -1, layer.shape[2])
+                embeddings = torch.gather(layer, 1, ind).squeeze(dim=1)
+            elif self.pooling_strategy == 'mean':
+                embeddings = layer.sum(dim=1) / attn_mask.sum(dim=1)
+            elif self.pooling_strategy == 'max':
+                embeddings = layer.max(dim=1).values
+            elif self.pooling_strategy == 'min':
+                embeddings = layer.min(dim=1).values
+
+            return embeddings.cpu().numpy()
