@@ -14,7 +14,7 @@ __all__ = ['BaseSparseNdArray']
 
 class BaseSparseNdArray(BaseNdArray):
     """
-    The base class for SparseNdArray.
+    The base class for :class:`SparseNdArray`.
 
     Do not use this class directly. Subclass should be used.
 
@@ -28,17 +28,19 @@ class BaseSparseNdArray(BaseNdArray):
         return jina_pb2.SparseNdArrayProto()
 
     def sparse_constructor(self, indices: 'np.ndarray', values: 'np.ndarray', shape: List[int]) -> AnySparseNdArray:
-        """ Sparse NdArray constructor, must be implemented by subclass
+        """
+        Sparse NdArray constructor, must be implemented by subclass.
 
         :param indices: the indices of the sparse array
         :param values: the values of the sparse array
         :param shape: the shape of the dense array
-        :return:
+        :return: Sparse NdArray
         """
         raise NotImplementedError
 
     def sparse_parser(self, value: AnySparseNdArray) -> Dict[str, Union['np.ndarray', List[int]]]:
-        """ Parsing a Sparse NdArray to indices, values and shape, must be implemented by subclass
+        """
+        Parse a Sparse NdArray to indices, values and shape, must be implemented by subclass.
 
         :param value: the sparse ndarray
         :return: a Dict with three entries {'indices': ..., 'values':..., 'shape':...}
