@@ -12,20 +12,20 @@ __all__ = ['SparseNdArray']
 
 
 class SparseNdArray(BaseSparseNdArray):
-    """Pytorch powered sparse ndarray, i.e. FloatTensor
+    """
+    Pytorch powered sparse ndarray, i.e. FloatTensor.
 
     .. seealso::
         https://pytorch.org/docs/stable/sparse.html
+
+    :param transpose_indices: in torch, the input to LongTensor is NOT a list of index tuples.
+    If you want to write your indices this way, you should transpose before passing them to the sparse constructor
+
+    .. note::
+        To comply with Tensorflow, `transpose_indices` is set to True by default
     """
 
     def __init__(self, transpose_indices: bool = True, *args, **kwargs):
-        """
-        :param transpose_indices: in torch, the input to LongTensor is NOT a list of index tuples.
-        If you want to write your indices this way, you should transpose before passing them to the sparse constructor
-
-        .. note::
-            To comply with Tensorflow, `transpose_indices` is set to True by default
-        """
         super().__init__(*args, **kwargs)
         self.transpose_indices = transpose_indices
 
