@@ -1,12 +1,12 @@
 from typing import Union, Optional, TypeVar, Dict
 
 from google.protobuf import json_format
-from google.protobuf.json_format import MessageToJson
 
-from ..sets import QueryLangSet, DocumentSet
+from ..mixin import ProtoTypeMixin
+from ..sets import QueryLangSet
 from ...enums import CompressAlgo, RequestType
 from ...excepts import BadRequestType
-from ...helper import get_random_identity, typename
+from ...helper import random_identity, typename
 from ...proto import jina_pb2
 
 _body_type = set(str(v).lower() for v in RequestType)
@@ -25,7 +25,7 @@ RequestSourceType = TypeVar('RequestSourceType',
                             jina_pb2.RequestProto, bytes, str, Dict)
 
 
-class Request:
+class Request(ProtoTypeMixin):
     """
     :class:`Request` is one of the **primitive data type** in Jina.
 
@@ -38,30 +38,33 @@ class Request:
     It overrides :meth:`__getattr__` to provide the same get/set interface as an
     :class:`jina_pb2.RequestProto` object.
 
+    :param request: The request.
+    :param envelope: EnvelopeProto object.
+    :param copy: Copy the request if ``copy`` is True.
     """
 
     def __init__(self, request: Union[bytes, dict, str, 'jina_pb2.RequestProto', None] = None,
                  envelope: Optional['jina_pb2.EnvelopeProto'] = None,
                  copy: bool = False):
-
+        """Set constructor method."""
         self._buffer = None
-        self._request = jina_pb2.RequestProto()  # type: 'jina_pb2.RequestProto'
+        self._pb_body = jina_pb2.RequestProto()  # type: 'jina_pb2.RequestProto'
         try:
             if isinstance(request, jina_pb2.RequestProto):
                 if copy:
-                    self._request.CopyFrom(request)
+                    self._pb_body.CopyFrom(request)
                 else:
-                    self._request = request
+                    self._pb_body = request
             elif isinstance(request, dict):
-                json_format.ParseDict(request, self._request)
+                json_format.ParseDict(request, self._pb_body)
             elif isinstance(request, str):
-                json_format.Parse(request, self._request)
+                json_format.Parse(request, self._pb_body)
             elif isinstance(request, bytes):
                 self._buffer = request
-                self._request = None
+                self._pb_body = None
             elif request is None:
                 # make sure every new request has a request id
-                self._request.request_id = get_random_identity()
+                self._pb_body.request_id = random_identity()
             elif request is not None:
                 # note ``None`` is not considered as a bad type
                 raise ValueError(f'{typename(request)} is not recognizable')
@@ -76,43 +79,61 @@ class Request:
         if name in _trigger_body_fields:
             return getattr(self.body, name)
         else:
-            return getattr(self.as_pb_object, name)
+            return getattr(self.proto, name)
 
     @property
     def body(self):
+        """Return the request type, raise ``ValueError`` if request_type not set."""
         if self._request_type:
-            return getattr(self.as_pb_object, self._request_type)
+            return getattr(self.proto, self._request_type)
         else:
             raise ValueError(f'"request_type" is not set yet')
 
     @property
     def _request_type(self) -> str:
-        return self.as_pb_object.WhichOneof('body')
+        return self.proto.WhichOneof('body')
 
     @property
     def request_type(self) -> Optional[str]:
-        """Return the request body type, when not set yet, return ``None``"""
+        """Return the request body type, when not set yet, return ``None``."""
         if self._request_type:
             return self.body.__class__.__name__
 
+    def as_typed_request(self, request_type: str):
+        """Change the request class according to the one_of value in ``body``."""
+        from .train import TrainRequest
+        from .search import SearchRequest
+        from .control import ControlRequest
+        from .index import IndexRequest
+        from .delete import DeleteRequest
+        from .update import UpdateRequest
+
+        rt = request_type.upper()
+        if rt.startswith(str(RequestType.TRAIN)):
+            self.__class__ = TrainRequest
+        elif rt.startswith(str(RequestType.DELETE)):
+            self.__class__ = DeleteRequest
+        elif rt.startswith(str(RequestType.INDEX)):
+            self.__class__ = IndexRequest
+        elif rt.startswith(str(RequestType.SEARCH)):
+            self.__class__ = SearchRequest
+        elif rt.startswith(str(RequestType.UPDATE)):
+            self.__class__ = UpdateRequest
+        elif rt.startswith(str(RequestType.CONTROL)):
+            self.__class__ = ControlRequest
+        else:
+            raise TypeError(f'{request_type} is not recognized')
+        return self
+
     @request_type.setter
     def request_type(self, value: str):
-        """Set the type of this request, but keep the body empty"""
+        """Set the type of this request, but keep the body empty."""
         value = value.lower()
         if value in _body_type:
-            getattr(self.as_pb_object, value).SetInParent()
+            getattr(self.proto, value).SetInParent()
         else:
             raise ValueError(f'{value} is not valid, must be one of {_body_type}')
-
-    @property
-    def docs(self) -> 'DocumentSet':
-        self.is_used = True
-        return DocumentSet(self.body.docs)
-
-    @property
-    def groundtruths(self) -> 'DocumentSet':
-        self.is_used = True
-        return DocumentSet(self.body.groundtruths)
+        self.as_typed_request(self._request_type)
 
     @staticmethod
     def _decompress(data: bytes, algorithm: str) -> bytes:
@@ -138,23 +159,23 @@ class Request:
         return data
 
     @property
-    def as_pb_object(self) -> 'jina_pb2.RequestProto':
+    def proto(self) -> 'jina_pb2.RequestProto':
         """
         Cast ``self`` to a :class:`jina_pb2.RequestProto`. This will trigger
-         :attr:`is_used`. Laziness will be broken and serialization will be recomputed when calling
-         :meth:`SerializeToString`.
+        :attr:`is_used`. Laziness will be broken and serialization will be recomputed when calling
+        :meth:`SerializeToString`.
         """
-        if self._request:
+        if self._pb_body:
             # if request is already given while init
             self.is_used = True
-            return self._request
+            return self._pb_body
         else:
             # if not then build one from buffer
             r = jina_pb2.RequestProto()
             _buffer = self._decompress(self._buffer, self._envelope.compression.algorithm if self._envelope else None)
             r.ParseFromString(_buffer)
             self.is_used = True
-            self._request = r
+            self._pb_body = r
             # # Though I can modify back the envelope, not sure if it is a good design:
             # # My intuition is: if the content is changed dramatically, e.g. from index to control request,
             # # then whatever writes on the envelope should be dropped
@@ -164,37 +185,32 @@ class Request:
             #     self._envelope.request_type = getattr(r, r.WhichOneof('body')).__class__.__name__
             return r
 
-    def SerializeToString(self):
+    def SerializeToString(self) -> bytes:
         if self.is_used:
-            return self.as_pb_object.SerializeToString()
+            return self.proto.SerializeToString()
         else:
             # no touch, skip serialization, return original
             return self._buffer
 
     @property
     def queryset(self) -> 'QueryLangSet':
+        """Get the queryset in :class:`QueryLangSet` type."""
         self.is_used = True
-        return QueryLangSet(self.as_pb_object.queryset)
+        return QueryLangSet(self.proto.queryset)
 
-    @property
-    def command(self) -> str:
-        self.is_used = True
-        return jina_pb2.RequestProto.ControlRequestProto.Command.Name(self.as_pb_object.control.command)
-
-    def to_json(self) -> str:
-        """Return the object in JSON string """
-        return MessageToJson(self._request)
-
-    def to_response(self) -> 'Response':
-        """Return a weak reference of this object but as :class:`Response` object. It gives a more
+    def as_response(self):
+        """
+        Return a weak reference of this object but as :class:`Response` object. It gives a more
         consistent semantics on the client.
         """
-        return Response(self._buffer)
+        base_cls = self.__class__
+        base_cls_name = self.__class__.__name__
+        self.__class__ = type(base_cls_name, (base_cls, Response), {})
 
 
-class Response(Request):
-    """Response is the :class:`Request` object returns from the flow. Right now it shares the same representation as
+class Response:
+    """
+    Response is the :class:`Request` object returns from the flow. Right now it shares the same representation as
     :class:`Request`. At 0.8.12, :class:`Response` is a simple alias. But it does give a more consistent semantic on
     the client API: send a :class:`Request` and receive a :class:`Response`.
-
     """
