@@ -1,5 +1,6 @@
 from typing import Optional
 
+from ..mixin import ProtoTypeMixin
 from ...excepts import BadNamedScoreType
 from ...helper import typename
 from ...proto import jina_pb2
@@ -7,7 +8,7 @@ from ...proto import jina_pb2
 __all__ = ['NamedScore']
 
 
-class NamedScore:
+class NamedScore(ProtoTypeMixin):
     """
      :class:`NamedScore` is one of the **primitive data type** in Jina.
 
@@ -36,25 +37,26 @@ class NamedScore:
              score_proto.value = 10.0
              score = NamedScore(score_proto)
 
+    :param score: The score to construct from, depending on the ``copy``,
+        it builds a view or a copy from it.
+    :type score: Optional[jina_pb2.NamedScoreProto]
+    :param copy: When ``score`` is given as a :class:`NamedScoreProto` object, build a
+        view (i.e. weak reference) from it or a deep copy from it.
+    :type copy: bool
+    :param kwargs: Other parameters to be set
+
      """
 
     def __init__(self, score: Optional[jina_pb2.NamedScoreProto] = None,
                  copy: bool = False, **kwargs):
-        """
-
-        :param score: the score to construct from, depending on the ``copy``,
-                it builds a view or a copy from it.
-        :param copy: when ``score`` is given as a :class:`NamedScoreProto` object, build a
-                view (i.e. weak reference) from it or a deep copy from it.
-        :param kwargs: other parameters to be set
-        """
-        self._score = jina_pb2.NamedScoreProto()
+        """Set constructor."""
+        self._pb_body = jina_pb2.NamedScoreProto()
         try:
             if isinstance(score, jina_pb2.NamedScoreProto):
                 if copy:
-                    self._score.CopyFrom(score)
+                    self._pb_body.CopyFrom(score)
                 else:
-                    self._score = score
+                    self._pb_body = score
             elif score is not None:
                 # note ``None`` is not considered as a bad type
                 raise ValueError(f'{typename(score)} is not recognizable')
@@ -63,30 +65,35 @@ class NamedScore:
 
         self.set_attrs(**kwargs)
 
-    def __getattr__(self, name: str):
-        return getattr(self._score, name)
+    @property
+    def ref_id(self) -> str:
+        """Returns computed score between doc ``id`` and ``ref_id``."""
+        return self._pb_body.ref_id
+
+    @ref_id.setter
+    def ref_id(self, val: str):
+        self._pb_body.ref_id = val
 
     def set_attrs(self, **kwargs):
-        """Bulk update Document fields with key-value specified in kwargs
+        """Udate Document fields with key-value specified in kwargs.
 
         .. seealso::
             :meth:`get_attrs` for bulk get attributes
-
         """
         for k, v in kwargs.items():
-            if isinstance(v, list) or isinstance(v, tuple):
-                self._score.ClearField(k)
-                getattr(self._score, k).extend(v)
+            if isinstance(v, (list, tuple)):
+                self._pb_body.ClearField(k)
+                getattr(self._pb_body, k).extend(v)
             elif isinstance(v, dict):
-                self._score.ClearField(k)
-                getattr(self._score, k).update(v)
+                self._pb_body.ClearField(k)
+                getattr(self._pb_body, k).update(v)
             else:
                 if hasattr(NamedScore, k) and isinstance(getattr(NamedScore, k), property) and getattr(NamedScore,
                                                                                                        k).fset:
                     # if class property has a setter
                     setattr(self, k, v)
-                elif hasattr(self._score, k):
+                elif hasattr(self._pb_body, k):
                     # no property setter, but proto has this attribute so fallback to proto
-                    setattr(self._score, k, v)
+                    setattr(self._pb_body, k, v)
                 else:
                     raise AttributeError(f'{k} is not recognized')
