@@ -1,37 +1,49 @@
 from collections.abc import MutableSequence
-from typing import Iterable, Union
+from typing import Iterable, Union, Dict
+
+
+try:
+    # when protobuf using Cpp backend
+    from google.protobuf.pyext._message import RepeatedCompositeContainer as RepeatedContainer
+except:
+    # when protobuf using Python backend
+    from google.protobuf.internal.containers import RepeatedCompositeFieldContainer as RepeatedContainer
 
-from google.protobuf.pyext._message import RepeatedCompositeContainer
 
 from ..querylang import QueryLang
-from ...drivers import BaseDriver
 from ...helper import typename
 from ...proto.jina_pb2 import QueryLangProto
 
-AcceptQueryLangType = Union[QueryLang, BaseDriver, QueryLangProto]
+AcceptQueryLangType = Union[QueryLang, QueryLangProto, Dict]
 
 __all__ = ['QueryLangSet', 'AcceptQueryLangType']
 
 
 class QueryLangSet(MutableSequence):
-    """:class:`QueryLangSet` is a mutable sequence of :class:`QueryLang`,
-    it gives an efficient view of a list of Document. One can iterate over it like
+    """
+    :class:`QueryLangSet` is a mutable sequence of :class:`QueryLang`.
+    It gives an efficient view of a list of Document. One can iterate over it like
     a generator but ALSO modify it, count it, get item.
+
+    :param querylang_protos: A list of :class:`QueryLangProto`
+    :type querylang_protos: :class:`RepeatedCompositeContainer`
     """
 
-    def __init__(self, querylang_protos: 'RepeatedCompositeContainer'):
+    def __init__(self, querylang_protos: 'RepeatedContainer'):
+        """Set constructor method."""
         super().__init__()
         self._querylangs_proto = querylang_protos
         self._querylangs_map = {}
 
     def insert(self, index: int, ql: 'QueryLang') -> None:
-        self._querylangs_proto.insert(index, ql.as_pb_object)
+        """Insert :param:`ql` at :param:`index` into `_querylangs_proto`."""
+        self._querylangs_proto.insert(index, ql.proto)
 
     def __setitem__(self, key, value: 'QueryLang'):
         if isinstance(key, int):
-            self._querylangs_proto[key].CopyFrom(value.as_pb_object)
+            self._querylangs_proto[key].CopyFrom(value.proto)
         elif isinstance(key, str):
-            self._querylangs_map[key].CopyFrom(value.as_pb_object)
+            self._querylangs_map[key].CopyFrom(value.proto)
         else:
             raise IndexError(f'do not support this index {key}')
 
@@ -54,13 +66,14 @@ class QueryLangSet(MutableSequence):
             raise IndexError(f'do not support this index {item}')
 
     def append(self, value: 'AcceptQueryLangType'):
+        """Append :param:`value` in `_querylangs_proto`."""
         q_pb = self._querylangs_proto.add()
-        if isinstance(value, BaseDriver):
-            q_pb.CopyFrom(QueryLang(value).as_pb_object)
+        if isinstance(value, Dict):
+            q_pb.CopyFrom(QueryLang(value).proto)
         elif isinstance(value, QueryLangProto):
             q_pb.CopyFrom(value)
         elif isinstance(value, QueryLang):
-            q_pb.CopyFrom(value.as_pb_object)
+            q_pb.CopyFrom(value.proto)
         else:
             raise TypeError(f'unknown type {typename(value)}')
 
@@ -69,9 +82,11 @@ class QueryLangSet(MutableSequence):
             self.append(q)
 
     def clear(self):
+        """Clear `_querylangs_proto` set."""
         del self._querylangs_proto[:]
 
     def reverse(self):
+        """Reverse order of `_querylangs_proto` set."""
         size = len(self._querylangs_proto)
         hi_idx = size - 1
         for i in range(int(size / 2)):
@@ -82,8 +97,6 @@ class QueryLangSet(MutableSequence):
             hi_idx -= 1
 
     def build(self):
-        """Build a name to QueryLang mapping so one can later index a QueryLang using
-        name as string key
-        """
+        """Build a name to QueryLang mapping so one can later index a QueryLang using name as string key."""
         # TODO This is a temp fix, QueryLangProto do not have an id field.
         self._querylangs_map = {q.name: q for q in self._querylangs_proto}
